@@ -1,4 +1,5 @@
 from odoo_somconnexio_python_client.client import Client
+from odoo_somconnexio_python_client.resources.address import Address
 
 from ..exceptions import ResourceNotFound
 
@@ -29,6 +30,8 @@ class Partner:
         sponsorship_code,
         sponsees_max,
         sponsees_number,
+        addresses,
+        banned_actions,
         **kwargs
     ):
         self.id = id
@@ -51,6 +54,10 @@ class Partner:
         self.sponsorship_code = sponsorship_code
         self.sponsees_max = sponsees_max
         self.sponsees_number = sponsees_number
+        self.addresses = []
+        for address in addresses:
+            self.addresses.append(Address(**address))
+        self.banned_actions = banned_actions
 
     @classmethod
     def get(cls, ref):
@@ -74,6 +81,29 @@ class Partner:
             }
         )
 
+    @classmethod
+    def check_sponsor(cls, vat, sponsor_code):
+        """
+        Check if partner can sponsor new partners.
+
+        :return: True or False
+        """
+        if not vat or not sponsor_code:
+            return False
+
+        url = "{}/{}".format(cls._url_path, "check_sponsor")
+        params = {
+            "vat": vat,
+            "sponsor_code": sponsor_code,
+        }
+        response_data = Client().get(
+            url,
+            params=params,
+        )
+        if not response_data:
+            raise ResourceNotFound(resource=cls.__name__, filter=params)
+        return response_data["result"] == "allowed", response_data["message"]
+
     @classmethod
     def _get(cls, id=None, params={}):
         if id:
@@ -82,7 +112,7 @@ class Partner:
             url = cls._url_path
 
         response_data = Client().get(
-            "{}".format(url),
+            url,
             params=params,
         )
         if not response_data:
